@@ -1,7 +1,6 @@
-from typing import Dict, List
+from cognite.client.data_classes import ContextualizationJob
 
 from cognite.experimental._context_client import ContextAPI
-from cognite.experimental.data_classes import ContextualizationJob
 
 
 class PNIDObjectDetectionAPI(ContextAPI):
@@ -16,4 +15,4 @@ class PNIDObjectDetectionAPI(ContextAPI):
         Returns:
             ContextualizationJob: Resulting queued job. Note that .results property of this job will block waiting for results.
         """
-        return self._run_job(job_path="/findobjects", status_path="/", file_id=file_id,)
+        return self._run_job(job_path="/findobjects", status_path="/findobjects/", file_id=file_id,)
